pub struct DepositForUserCall {
pub user: Address,
}Expand description
Container type for all input parameters for the depositForUser function with signature depositForUser(address) and selector 0x6a523c5e
Fields
user: AddressTrait Implementations
impl AbiArrayType for DepositForUserCall
Sourceimpl AbiDecode for DepositForUserCall
impl AbiDecode for DepositForUserCall
Sourceimpl AbiEncode for DepositForUserCall
impl AbiEncode for DepositForUserCall
Sourceimpl AbiType for DepositForUserCall
impl AbiType for DepositForUserCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for DepositForUserCall
impl Clone for DepositForUserCall
Sourcefn clone(&self) -> DepositForUserCall
fn clone(&self) -> DepositForUserCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DepositForUserCall
impl Debug for DepositForUserCall
Sourceimpl Default for DepositForUserCall
impl Default for DepositForUserCall
Sourcefn default() -> DepositForUserCall
fn default() -> DepositForUserCall
Returns the “default value” for a type. Read more
Sourceimpl Display for DepositForUserCall
impl Display for DepositForUserCall
impl Eq for DepositForUserCall
Sourceimpl EthCall for DepositForUserCall
impl EthCall for DepositForUserCall
Sourceimpl From<DepositForUserCall> for LedgerContractCalls
impl From<DepositForUserCall> for LedgerContractCalls
Sourcefn from(value: DepositForUserCall) -> Self
fn from(value: DepositForUserCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for DepositForUserCall
impl Hash for DepositForUserCall
Sourceimpl PartialEq for DepositForUserCall
impl PartialEq for DepositForUserCall
Sourcefn eq(&self, other: &DepositForUserCall) -> bool
fn eq(&self, other: &DepositForUserCall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DepositForUserCall
Sourceimpl Tokenizable for DepositForUserCall
impl Tokenizable for DepositForUserCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl TokenizableItem for DepositForUserCall