pub struct StableBalanceReturn(pub I256);Expand description
Container type for all return fields from the stableBalance function with signature stableBalance(address) and selector 0x3804450b
Tuple Fields
0: I256Trait Implementations
impl AbiArrayType for StableBalanceReturn
Sourceimpl AbiDecode for StableBalanceReturn
impl AbiDecode for StableBalanceReturn
Sourceimpl AbiEncode for StableBalanceReturn
impl AbiEncode for StableBalanceReturn
Sourceimpl AbiType for StableBalanceReturn
impl AbiType for StableBalanceReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for StableBalanceReturn
impl Clone for StableBalanceReturn
Sourcefn clone(&self) -> StableBalanceReturn
fn clone(&self) -> StableBalanceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StableBalanceReturn
impl Debug for StableBalanceReturn
Sourceimpl Default for StableBalanceReturn
impl Default for StableBalanceReturn
Sourcefn default() -> StableBalanceReturn
fn default() -> StableBalanceReturn
Returns the “default value” for a type. Read more
impl Eq for StableBalanceReturn
Sourceimpl Hash for StableBalanceReturn
impl Hash for StableBalanceReturn
Sourceimpl PartialEq for StableBalanceReturn
impl PartialEq for StableBalanceReturn
Sourcefn eq(&self, other: &StableBalanceReturn) -> bool
fn eq(&self, other: &StableBalanceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StableBalanceReturn
Sourceimpl Tokenizable for StableBalanceReturn
impl Tokenizable for StableBalanceReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl TokenizableItem for StableBalanceReturn