pub struct WithdrawCall {
pub amount: I256,
}Expand description
Container type for all input parameters for the withdraw function with signature withdraw(int256) and selector 0x7e62eab8
Fields
amount: I256Trait Implementations
impl AbiArrayType for WithdrawCall
Sourceimpl AbiDecode for WithdrawCall
impl AbiDecode for WithdrawCall
Sourceimpl AbiEncode for WithdrawCall
impl AbiEncode for WithdrawCall
Sourceimpl AbiType for WithdrawCall
impl AbiType for WithdrawCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for WithdrawCall
impl Clone for WithdrawCall
Sourcefn clone(&self) -> WithdrawCall
fn clone(&self) -> WithdrawCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithdrawCall
impl Debug for WithdrawCall
Sourceimpl Default for WithdrawCall
impl Default for WithdrawCall
Sourcefn default() -> WithdrawCall
fn default() -> WithdrawCall
Returns the “default value” for a type. Read more
Sourceimpl Display for WithdrawCall
impl Display for WithdrawCall
impl Eq for WithdrawCall
Sourceimpl EthCall for WithdrawCall
impl EthCall for WithdrawCall
Sourceimpl From<WithdrawCall> for LedgerContractCalls
impl From<WithdrawCall> for LedgerContractCalls
Sourcefn from(value: WithdrawCall) -> Self
fn from(value: WithdrawCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for WithdrawCall
impl Hash for WithdrawCall
Sourceimpl PartialEq for WithdrawCall
impl PartialEq for WithdrawCall
Sourcefn eq(&self, other: &WithdrawCall) -> bool
fn eq(&self, other: &WithdrawCall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WithdrawCall
Sourceimpl Tokenizable for WithdrawCall
impl Tokenizable for WithdrawCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl TokenizableItem for WithdrawCall