pub struct WithdrawRequest {
pub timestamp: U256,
pub amount: U256,
}Expand description
WithdrawRequest(uint256,uint256)
Fields
timestamp: U256amount: U256Trait Implementations
impl AbiArrayType for WithdrawRequest
Sourceimpl AbiDecode for WithdrawRequest
impl AbiDecode for WithdrawRequest
Sourceimpl AbiEncode for WithdrawRequest
impl AbiEncode for WithdrawRequest
Sourceimpl AbiType for WithdrawRequest
impl AbiType for WithdrawRequest
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for WithdrawRequest
impl Clone for WithdrawRequest
Sourcefn clone(&self) -> WithdrawRequest
fn clone(&self) -> WithdrawRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithdrawRequest
impl Debug for WithdrawRequest
Sourceimpl Default for WithdrawRequest
impl Default for WithdrawRequest
Sourcefn default() -> WithdrawRequest
fn default() -> WithdrawRequest
Returns the “default value” for a type. Read more
impl Eq for WithdrawRequest
Sourceimpl Hash for WithdrawRequest
impl Hash for WithdrawRequest
Sourceimpl PartialEq for WithdrawRequest
impl PartialEq for WithdrawRequest
Sourcefn eq(&self, other: &WithdrawRequest) -> bool
fn eq(&self, other: &WithdrawRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WithdrawRequest
Sourceimpl Tokenizable for WithdrawRequest
impl Tokenizable for WithdrawRequest
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl TokenizableItem for WithdrawRequest