pub struct RemovePermittedAuthMethodCall {
pub token_id: U256,
pub auth_method_type: U256,
pub id: Bytes,
}Expand description
Container type for all input parameters for the removePermittedAuthMethod function with signature removePermittedAuthMethod(uint256,uint256,bytes) and selector 0x66fc6541
Fields
token_id: U256auth_method_type: U256id: BytesTrait Implementations
impl AbiArrayType for RemovePermittedAuthMethodCall
Sourceimpl AbiType for RemovePermittedAuthMethodCall
impl AbiType for RemovePermittedAuthMethodCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for RemovePermittedAuthMethodCall
impl Clone for RemovePermittedAuthMethodCall
Sourcefn clone(&self) -> RemovePermittedAuthMethodCall
fn clone(&self) -> RemovePermittedAuthMethodCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RemovePermittedAuthMethodCall
impl Default for RemovePermittedAuthMethodCall
Sourcefn default() -> RemovePermittedAuthMethodCall
fn default() -> RemovePermittedAuthMethodCall
Returns the “default value” for a type. Read more
impl Eq for RemovePermittedAuthMethodCall
Sourceimpl From<RemovePermittedAuthMethodCall> for PkpPermissionsContractCalls
impl From<RemovePermittedAuthMethodCall> for PkpPermissionsContractCalls
Sourcefn from(value: RemovePermittedAuthMethodCall) -> Self
fn from(value: RemovePermittedAuthMethodCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for RemovePermittedAuthMethodCall
impl Hash for RemovePermittedAuthMethodCall
Sourceimpl PartialEq for RemovePermittedAuthMethodCall
impl PartialEq for RemovePermittedAuthMethodCall
Sourcefn eq(&self, other: &RemovePermittedAuthMethodCall) -> bool
fn eq(&self, other: &RemovePermittedAuthMethodCall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemovePermittedAuthMethodCall
Sourceimpl Tokenizable for RemovePermittedAuthMethodCall
impl Tokenizable for RemovePermittedAuthMethodCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl TokenizableItem for RemovePermittedAuthMethodCall