pub struct GetNodesForRequestCall {
pub realm_id: U256,
pub product_ids: Vec<U256>,
}Expand description
Container type for all input parameters for the getNodesForRequest function with signature getNodesForRequest(uint256,uint256[]) and selector 0x224d9449
Fields
realm_id: U256product_ids: Vec<U256>Trait Implementations
impl AbiArrayType for GetNodesForRequestCall
Sourceimpl AbiDecode for GetNodesForRequestCall
impl AbiDecode for GetNodesForRequestCall
Sourceimpl AbiEncode for GetNodesForRequestCall
impl AbiEncode for GetNodesForRequestCall
Sourceimpl AbiType for GetNodesForRequestCall
impl AbiType for GetNodesForRequestCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for GetNodesForRequestCall
impl Clone for GetNodesForRequestCall
Sourcefn clone(&self) -> GetNodesForRequestCall
fn clone(&self) -> GetNodesForRequestCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetNodesForRequestCall
impl Debug for GetNodesForRequestCall
Sourceimpl Default for GetNodesForRequestCall
impl Default for GetNodesForRequestCall
Sourcefn default() -> GetNodesForRequestCall
fn default() -> GetNodesForRequestCall
Returns the “default value” for a type. Read more
Sourceimpl Display for GetNodesForRequestCall
impl Display for GetNodesForRequestCall
impl Eq for GetNodesForRequestCall
Sourceimpl EthCall for GetNodesForRequestCall
impl EthCall for GetNodesForRequestCall
Sourceimpl Hash for GetNodesForRequestCall
impl Hash for GetNodesForRequestCall
Sourceimpl PartialEq for GetNodesForRequestCall
impl PartialEq for GetNodesForRequestCall
Sourcefn eq(&self, other: &GetNodesForRequestCall) -> bool
fn eq(&self, other: &GetNodesForRequestCall) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GetNodesForRequestCall
Sourceimpl Tokenizable for GetNodesForRequestCall
impl Tokenizable for GetNodesForRequestCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl TokenizableItem for GetNodesForRequestCall